==> zend-framework_1.10.3.orig.tar.gz: zend-framework-1.10.3/tests/Zend/Barcode/Object/_files/Ean8_123456_oriented_instructions.php <==
<?php
return
array (
  0 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 53,
        1 => 0,
      ),
      1 => 
      array (
        0 => 0,
        1 => 30,
      ),
      2 => 
      array (
        0 => 41,
        1 => 100,
      ),
      3 => 
      array (
        0 => 94,
        1 => 70,
      ),
    ),
    'color' => 16777215,
    'filled' => true,
  ),
  1 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 58,
        1 => 8,
      ),
      1 => 
      array (
        0 => 11,
        1 => 36,
      ),
      2 => 
      array (
        0 => 11,
        1 => 36,
      ),
      3 => 
      array (
        0 => 58,
        1 => 8,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  2 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 59,
        1 => 10,
      ),
      1 => 
      array (
        0 => 12,
        1 => 37,
      ),
      2 => 
      array (
        0 => 12,
        1 => 37,
      ),
      3 => 
      array (
        0 => 59,
        1 => 10,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  3 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 61,
        1 => 13,
      ),
      1 => 
      array (
        0 => 18,
        1 => 38,
      ),
      2 => 
      array (
        0 => 18,
        1 => 38,
      ),
      3 => 
      array (
        0 => 61,
        1 => 13,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  4 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 62,
        1 => 14,
      ),
      1 => 
      array (
        0 => 18,
        1 => 39,
      ),
      2 => 
      array (
        0 => 18,
        1 => 39,
      ),
      3 => 
      array (
        0 => 62,
        1 => 14,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  5 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 63,
        1 => 16,
      ),
      1 => 
      array (
        0 => 19,
        1 => 41,
      ),
      2 => 
      array (
        0 => 19,
        1 => 41,
      ),
      3 => 
      array (
        0 => 63,
        1 => 16,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  6 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 64,
        1 => 19,
      ),
      1 => 
      array (
        0 => 21,
        1 => 44,
      ),
      2 => 
      array (
        0 => 21,
        1 => 44,
      ),
      3 => 
      array (
        0 => 64,
        1 => 19,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  7 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 65,
        1 => 19,
      ),
      1 => 
      array (
        0 => 21,
        1 => 44,
      ),
      2 => 
      array (
        0 => 21,
        1 => 44,
      ),
      3 => 
      array (
        0 => 65,
        1 => 19,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  8 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 66,
        1 => 22,
      ),
      1 => 
      array (
        0 => 23,
        1 => 47,
      ),
      2 => 
      array (
        0 => 23,
        1 => 47,
      ),
      3 => 
      array (
        0 => 66,
        1 => 22,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  9 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 68,
        1 => 25,
      ),
      1 => 
      array (
        0 => 24,
        1 => 50,
      ),
      2 => 
      array (
        0 => 24,
        1 => 50,
      ),
      3 => 
      array (
        0 => 68,
        1 => 25,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  10 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 69,
        1 => 27,
      ),
      1 => 
      array (
        0 => 26,
        1 => 52,
      ),
      2 => 
      array (
        0 => 26,
        1 => 52,
      ),
      3 => 
      array (
        0 => 69,
        1 => 27,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  11 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 70,
        1 => 28,
      ),
      1 => 
      array (
        0 => 26,
        1 => 53,
      ),
      2 => 
      array (
        0 => 26,
        1 => 53,
      ),
      3 => 
      array (
        0 => 70,
        1 => 28,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  12 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 71,
        1 => 30,
      ),
      1 => 
      array (
        0 => 27,
        1 => 55,
      ),
      2 => 
      array (
        0 => 27,
        1 => 55,
      ),
      3 => 
      array (
        0 => 71,
        1 => 30,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  13 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 71,
        1 => 31,
      ),
      1 => 
      array (
        0 => 28,
        1 => 56,
      ),
      2 => 
      array (
        0 => 28,
        1 => 56,
      ),
      3 => 
      array (
        0 => 71,
        1 => 31,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  14 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 72,
        1 => 32,
      ),
      1 => 
      array (
        0 => 28,
        1 => 57,
      ),
      2 => 
      array (
        0 => 28,
        1 => 57,
      ),
      3 => 
      array (
        0 => 72,
        1 => 32,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  15 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 72,
        1 => 32,
      ),
      1 => 
      array (
        0 => 29,
        1 => 57,
      ),
      2 => 
      array (
        0 => 29,
        1 => 57,
      ),
      3 => 
      array (
        0 => 72,
        1 => 32,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  16 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 73,
        1 => 34,
      ),
      1 => 
      array (
        0 => 30,
        1 => 59,
      ),
      2 => 
      array (
        0 => 30,
        1 => 59,
      ),
      3 => 
      array (
        0 => 73,
        1 => 34,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  17 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 74,
        1 => 36,
      ),
      1 => 
      array (
        0 => 27,
        1 => 63,
      ),
      2 => 
      array (
        0 => 27,
        1 => 63,
      ),
      3 => 
      array (
        0 => 74,
        1 => 36,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  18 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 75,
        1 => 38,
      ),
      1 => 
      array (
        0 => 28,
        1 => 65,
      ),
      2 => 
      array (
        0 => 28,
        1 => 65,
      ),
      3 => 
      array (
        0 => 75,
        1 => 38,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  19 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 76,
        1 => 39,
      ),
      1 => 
      array (
        0 => 33,
        1 => 64,
      ),
      2 => 
      array (
        0 => 33,
        1 => 64,
      ),
      3 => 
      array (
        0 => 76,
        1 => 39,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  20 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 77,
        1 => 41,
      ),
      1 => 
      array (
        0 => 34,
        1 => 66,
      ),
      2 => 
      array (
        0 => 34,
        1 => 66,
      ),
      3 => 
      array (
        0 => 77,
        1 => 41,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  21 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 78,
        1 => 42,
      ),
      1 => 
      array (
        0 => 34,
        1 => 67,
      ),
      2 => 
      array (
        0 => 34,
        1 => 67,
      ),
      3 => 
      array (
        0 => 78,
        1 => 42,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  22 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 78,
        1 => 43,
      ),
      1 => 
      array (
        0 => 35,
        1 => 68,
      ),
      2 => 
      array (
        0 => 35,
        1 => 68,
      ),
      3 => 
      array (
        0 => 78,
        1 => 43,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  23 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 80,
        1 => 45,
      ),
      1 => 
      array (
        0 => 36,
        1 => 70,
      ),
      2 => 
      array (
        0 => 36,
        1 => 70,
      ),
      3 => 
      array (
        0 => 80,
        1 => 45,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  24 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 81,
        1 => 48,
      ),
      1 => 
      array (
        0 => 38,
        1 => 73,
      ),
      2 => 
      array (
        0 => 38,
        1 => 73,
      ),
      3 => 
      array (
        0 => 81,
        1 => 48,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  25 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 82,
        1 => 49,
      ),
      1 => 
      array (
        0 => 38,
        1 => 74,
      ),
      2 => 
      array (
        0 => 38,
        1 => 74,
      ),
      3 => 
      array (
        0 => 82,
        1 => 49,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  26 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 82,
        1 => 50,
      ),
      1 => 
      array (
        0 => 39,
        1 => 75,
      ),
      2 => 
      array (
        0 => 39,
        1 => 75,
      ),
      3 => 
      array (
        0 => 82,
        1 => 50,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  27 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 83,
        1 => 51,
      ),
      1 => 
      array (
        0 => 40,
        1 => 76,
      ),
      2 => 
      array (
        0 => 40,
        1 => 76,
      ),
      3 => 
      array (
        0 => 83,
        1 => 51,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  28 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 84,
        1 => 53,
      ),
      1 => 
      array (
        0 => 41,
        1 => 78,
      ),
      2 => 
      array (
        0 => 41,
        1 => 78,
      ),
      3 => 
      array (
        0 => 84,
        1 => 53,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  29 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 87,
        1 => 58,
      ),
      1 => 
      array (
        0 => 43,
        1 => 83,
      ),
      2 => 
      array (
        0 => 43,
        1 => 83,
      ),
      3 => 
      array (
        0 => 87,
        1 => 58,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  30 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 88,
        1 => 60,
      ),
      1 => 
      array (
        0 => 45,
        1 => 85,
      ),
      2 => 
      array (
        0 => 45,
        1 => 85,
      ),
      3 => 
      array (
        0 => 88,
        1 => 60,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  31 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 89,
        1 => 61,
      ),
      1 => 
      array (
        0 => 45,
        1 => 86,
      ),
      2 => 
      array (
        0 => 45,
        1 => 86,
      ),
      3 => 
      array (
        0 => 89,
        1 => 61,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  32 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 89,
        1 => 62,
      ),
      1 => 
      array (
        0 => 46,
        1 => 87,
      ),
      2 => 
      array (
        0 => 46,
        1 => 87,
      ),
      3 => 
      array (
        0 => 89,
        1 => 62,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  33 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 90,
        1 => 64,
      ),
      1 => 
      array (
        0 => 43,
        1 => 91,
      ),
      2 => 
      array (
        0 => 43,
        1 => 91,
      ),
      3 => 
      array (
        0 => 90,
        1 => 64,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  34 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 91,
        1 => 65,
      ),
      1 => 
      array (
        0 => 44,
        1 => 93,
      ),
      2 => 
      array (
        0 => 44,
        1 => 93,
      ),
      3 => 
      array (
        0 => 91,
        1 => 65,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  35 => 
  array (
    'type' => 'text',
    'text' => '0',
    'size' => 10,
    'position' => 
    array (
      0 => 7,
      1 => 41,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  36 => 
  array (
    'type' => 'text',
    'text' => '1',
    'size' => 10,
    'position' => 
    array (
      0 => 10,
      1 => 47,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  37 => 
  array (
    'type' => 'text',
    'text' => '2',
    'size' => 10,
    'position' => 
    array (
      0 => 14,
      1 => 53,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  38 => 
  array (
    'type' => 'text',
    'text' => '3',
    'size' => 10,
    'position' => 
    array (
      0 => 17,
      1 => 59,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  39 => 
  array (
    'type' => 'text',
    'text' => '4',
    'size' => 10,
    'position' => 
    array (
      0 => 23,
      1 => 69,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  40 => 
  array (
    'type' => 'text',
    'text' => '5',
    'size' => 10,
    'position' => 
    array (
      0 => 26,
      1 => 75,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  41 => 
  array (
    'type' => 'text',
    'text' => '6',
    'size' => 10,
    'position' => 
    array (
      0 => 30,
      1 => 81,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
  42 => 
  array (
    'type' => 'text',
    'text' => '5',
    'size' => 10,
    'position' => 
    array (
      0 => 33,
      1 => 87,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => -60,
  ),
);

==> zend-framework_1.11.11.orig.tar.gz: zend-framework-1.11.11/tests/Zend/Barcode/Object/_files/Ean5_45678_oriented_instructions.php <==
<?php
return
array (
  0 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 53,
        1 => 0,
      ),
      1 => 
      array (
        0 => 0,
        1 => 30,
      ),
      2 => 
      array (
        0 => 34,
        1 => 88,
      ),
      3 => 
      array (
        0 => 87,
        1 => 58,
      ),
    ),
    'color' => 16777215,
    'filled' => true,
  ),
  1 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 59,
        1 => 9,
      ),
      1 => 
      array (
        0 => 15,
        1 => 34,
      ),
      2 => 
      array (
        0 => 15,
        1 => 34,
      ),
      3 => 
      array (
        0 => 59,
        1 => 9,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  2 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 60,
        1 => 11,
      ),
      1 => 
      array (
        0 => 16,
        1 => 36,
      ),
      2 => 
      array (
        0 => 16,
        1 => 36,
      ),
      3 => 
      array (
        0 => 60,
        1 => 11,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  3 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 60,
        1 => 12,
      ),
      1 => 
      array (
        0 => 17,
        1 => 37,
      ),
      2 => 
      array (
        0 => 17,
        1 => 37,
      ),
      3 => 
      array (
        0 => 60,
        1 => 12,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  4 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 62,
        1 => 14,
      ),
      1 => 
      array (
        0 => 18,
        1 => 39,
      ),
      2 => 
      array (
        0 => 18,
        1 => 39,
      ),
      3 => 
      array (
        0 => 62,
        1 => 14,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  5 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 62,
        1 => 15,
      ),
      1 => 
      array (
        0 => 19,
        1 => 40,
      ),
      2 => 
      array (
        0 => 19,
        1 => 40,
      ),
      3 => 
      array (
        0 => 62,
        1 => 15,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  6 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 63,
        1 => 16,
      ),
      1 => 
      array (
        0 => 19,
        1 => 41,
      ),
      2 => 
      array (
        0 => 19,
        1 => 41,
      ),
      3 => 
      array (
        0 => 63,
        1 => 16,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  7 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 64,
        1 => 18,
      ),
      1 => 
      array (
        0 => 20,
        1 => 43,
      ),
      2 => 
      array (
        0 => 20,
        1 => 43,
      ),
      3 => 
      array (
        0 => 64,
        1 => 18,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  8 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 65,
        1 => 19,
      ),
      1 => 
      array (
        0 => 21,
        1 => 44,
      ),
      2 => 
      array (
        0 => 21,
        1 => 44,
      ),
      3 => 
      array (
        0 => 65,
        1 => 19,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  9 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 66,
        1 => 21,
      ),
      1 => 
      array (
        0 => 22,
        1 => 46,
      ),
      2 => 
      array (
        0 => 22,
        1 => 46,
      ),
      3 => 
      array (
        0 => 66,
        1 => 21,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  10 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 66,
        1 => 22,
      ),
      1 => 
      array (
        0 => 23,
        1 => 47,
      ),
      2 => 
      array (
        0 => 23,
        1 => 47,
      ),
      3 => 
      array (
        0 => 66,
        1 => 22,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  11 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 68,
        1 => 25,
      ),
      1 => 
      array (
        0 => 25,
        1 => 50,
      ),
      2 => 
      array (
        0 => 25,
        1 => 50,
      ),
      3 => 
      array (
        0 => 68,
        1 => 25,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  12 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 69,
        1 => 27,
      ),
      1 => 
      array (
        0 => 26,
        1 => 52,
      ),
      2 => 
      array (
        0 => 26,
        1 => 52,
      ),
      3 => 
      array (
        0 => 69,
        1 => 27,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  13 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 70,
        1 => 29,
      ),
      1 => 
      array (
        0 => 27,
        1 => 54,
      ),
      2 => 
      array (
        0 => 27,
        1 => 54,
      ),
      3 => 
      array (
        0 => 70,
        1 => 29,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  14 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 71,
        1 => 31,
      ),
      1 => 
      array (
        0 => 28,
        1 => 56,
      ),
      2 => 
      array (
        0 => 28,
        1 => 56,
      ),
      3 => 
      array (
        0 => 71,
        1 => 31,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  15 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 72,
        1 => 32,
      ),
      1 => 
      array (
        0 => 28,
        1 => 57,
      ),
      2 => 
      array (
        0 => 28,
        1 => 57,
      ),
      3 => 
      array (
        0 => 72,
        1 => 32,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  16 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 72,
        1 => 32,
      ),
      1 => 
      array (
        0 => 29,
        1 => 57,
      ),
      2 => 
      array (
        0 => 29,
        1 => 57,
      ),
      3 => 
      array (
        0 => 72,
        1 => 32,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  17 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 73,
        1 => 33,
      ),
      1 => 
      array (
        0 => 29,
        1 => 58,
      ),
      2 => 
      array (
        0 => 29,
        1 => 58,
      ),
      3 => 
      array (
        0 => 73,
        1 => 33,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  18 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 74,
        1 => 35,
      ),
      1 => 
      array (
        0 => 30,
        1 => 60,
      ),
      2 => 
      array (
        0 => 30,
        1 => 60,
      ),
      3 => 
      array (
        0 => 74,
        1 => 35,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  19 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 75,
        1 => 38,
      ),
      1 => 
      array (
        0 => 32,
        1 => 63,
      ),
      2 => 
      array (
        0 => 32,
        1 => 63,
      ),
      3 => 
      array (
        0 => 75,
        1 => 38,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  20 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 77,
        1 => 41,
      ),
      1 => 
      array (
        0 => 34,
        1 => 66,
      ),
      2 => 
      array (
        0 => 34,
        1 => 66,
      ),
      3 => 
      array (
        0 => 77,
        1 => 41,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  21 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 78,
        1 => 43,
      ),
      1 => 
      array (
        0 => 35,
        1 => 68,
      ),
      2 => 
      array (
        0 => 35,
        1 => 68,
      ),
      3 => 
      array (
        0 => 78,
        1 => 43,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  22 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 79,
        1 => 45,
      ),
      1 => 
      array (
        0 => 36,
        1 => 70,
      ),
      2 => 
      array (
        0 => 36,
        1 => 70,
      ),
      3 => 
      array (
        0 => 79,
        1 => 45,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  23 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 80,
        1 => 45,
      ),
      1 => 
      array (
        0 => 36,
        1 => 70,
      ),
      2 => 
      array (
        0 => 36,
        1 => 70,
      ),
      3 => 
      array (
        0 => 80,
        1 => 45,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  24 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 81,
        1 => 47,
      ),
      1 => 
      array (
        0 => 37,
        1 => 72,
      ),
      2 => 
      array (
        0 => 37,
        1 => 72,
      ),
      3 => 
      array (
        0 => 81,
        1 => 47,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  25 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 81,
        1 => 48,
      ),
      1 => 
      array (
        0 => 38,
        1 => 73,
      ),
      2 => 
      array (
        0 => 38,
        1 => 73,
      ),
      3 => 
      array (
        0 => 81,
        1 => 48,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  26 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 82,
        1 => 49,
      ),
      1 => 
      array (
        0 => 38,
        1 => 74,
      ),
      2 => 
      array (
        0 => 38,
        1 => 74,
      ),
      3 => 
      array (
        0 => 82,
        1 => 49,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  27 => 
  array (
    'type' => 'text',
    'text' => '45678',
    'size' => 10,
    'position' => 
    array (
      0 => 17,
      1 => 59,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'center',
    'orientation' => -60,
  ),
);
